[test](broken-link)
[test](broken-link.md)

[working link](project.md)

[working link no ext](project.md)

![test](puppy.png)
![test](puppy.jpg)

![](puppy.png)
![](puppy)
![](puppy.jpg)

[[Broken Wiki Link]]

[[Project]]

[[Project#My Project|This is my totally kewl project!]]

[Abs Link (no Ext)](/other-project/project)
[Abs Link](/other-project/project.md)

[[Index]]
